@@ -88,7 +88,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 
   m_FlowTable.signal_field_edited().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_edited) );
   show_all();
-
+   
   m_ignore_signals = false;
 }
 
@@ -124,15 +124,15 @@ void Box_Data_Details::fill_from_database_layout()
 
   //Remove existing child widgets:
   m_FlowTable.remove_all();
-            
+                          
   Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
   if(document)
-  {            
+  {          
     Document_Glom::type_mapLayoutGroupSequence layout_groups = document->get_data_layout_groups_plus_new_fields("details", m_strTableName);
     for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
       const LayoutGroup& group = iter->second;
- 
+  
       if(group.m_group_name != "others")
       {
         FlowTableWithFields::type_map_field_sequence fields;
@@ -422,19 +422,13 @@ void Box_Data_Details::on_button_nav_last()
     signal_nav_last().emit();
 }
 
-Field Box_Data_Details::get_Entered_Field(guint index) const
+Gnome::Gda::Value Box_Data_Details::get_entered_field_data(const Field& field) const
 {
-  //Get Gnome::Gda::FieldAttributes from base:
-  Field FieldResult = Box_Data::get_Entered_Field(index);
- /* TODO_port
-  //Get text from widget:
-  if(index < get_Entered_Field_count())
-  {
-    const Glib::ustring& strData = m_AddDel.get_value(index);
-    FieldResult.set_data(strData);
-  }
-  */
-  return FieldResult;
+  const EntryGlom* entry = m_FlowTable.get_field(field);
+  if(entry)
+    return entry->get_value();
+  else
+    return Gnome::Gda::Value(); //null.
 }
 
 Gnome::Gda::Value Box_Data_Details::get_primary_key_value_selected()
@@ -470,7 +464,7 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
  /* TODO_port
   guint iKey = 0;
   bool bTest = get_field_index(strFromKeyName, iKey);
-  Glib::ustring strFromKeyValue = get_Entered_Field(iKey).get_data();
+  Glib::ustring strFromKeyValue = get_entered_field_data(iKey).get_data();
 
   if(strFromKeyValue.size() == 0)
   {
