@@ -27,9 +27,11 @@ Box_Data_Details_Find::Box_Data_Details_Find()
    m_strHint = gettext("Enter the search criteria and click [Find]\n Glom will then change to Data mode to display the results.");
 
   //Instead of nav buttons:
-  m_HBox.pack_end(m_Button_Find, Gtk::PACK_EXPAND_WIDGET);
+  m_HBox.pack_end(m_Button_Find, Gtk::PACK_SHRINK);
 
-  show_all();
+  m_Button_Find.property_can_default() = true; //TODO: Make this a real method in gtkmm?
+
+  show_all_children();
 }
 
 Box_Data_Details_Find::~Box_Data_Details_Find()
@@ -40,23 +42,14 @@ Box_Data_Details_Find::~Box_Data_Details_Find()
 
 void Box_Data_Details_Find::fill_from_database()
 {
-/* TOOD_port
+  Bakery::BusyCursor(*get_app_window());
+
   Box_DB_Table::fill_from_database();
 
-  for(guint i = 0; i < m_Fields.size(); i ++)
-  {
-    //Field value:
-    guint uiRow = i;
-    if(uiRow >= m_AddDel.get_count())
-      uiRow = m_AddDel.add_item();
+  type_vecFields listFieldsToShow = get_fields_to_show();
+  m_Fields =  listFieldsToShow;
 
-    //Field name:
-    const Glib::ustring& strFieldName = m_Fields[i].get_name();
-    m_AddDel.set_item_title(uiRow, strFieldName);
-  }
-
-  */
-  fill_end();
+  fill_from_database_layout(); //TODO: Only do this when the layout has changed.
 }
 
 void Box_Data_Details_Find::fill_related()
@@ -96,3 +89,9 @@ void Box_Data_Details_Find::on_AddDel_user_changed(guint /* row */, guint /* col
   //Don't do anything.
   //This just blocks the method in the base class.
 }
+
+Gtk::Widget* Box_Data_Details_Find::get_default_button() //override
+{
+  return &m_Button_Find;
+}
+ 
